#VLAN Change CLI
#2021 - Angelo Poggi

import click
from vlanchange import vlan_change

@click.group(help =
            '''Change a VLAN to a new VLAN on a switch with that VLAN tagged''')
def cli():
    pass

@click.command()
@click.option(
    '--source', '-s', help="Source VLAN you want to change",
    required=True,
    type=str
)
@click.option(
    '--destination', '-d', help="Vlan you want to currently use",
    required=True,
    type=str
)
@click.option(
    '--name', '-n', help="Name of the Vlan",
    required=True,
    type=str
)
@click.option(
    '--switch', '-sw', help="Switch you want to make the changes on",
    required=True,
    type=str
)
def modify():
    return vlan_change()



import os
from dotenv import load_dotenv,find_dotenv
from pathlib import Path  # Python 3.6+ only

env_file = find_dotenv()
try:
    load_dotenv(env_file)
except:
    print("Please create a local .env file with local credentials")
    exit()

ROUTER_USERNAME = os.getenv("ROUTER_USERNAME")
ROUTER_PASSWORD = os.getenv("ROUTER_PASSWORD")
SECRET = os.getenv("SECRET")




#VLAN change
#2021 - Angelo Poggi

import click
from vlan_change.creds import ROUTER_PASSWORD, ROUTER_USERNAME, SECRET
from netmiko import ConnectHandler

def vlan_change(source, target,name, switch):
    device = {
        'device_type' : 'cisco_ios',
        'ip' : switch,
        'username' : ROUTER_USERNAME,
        'password' : ROUTER_PASSWORD,
        'secret' : SECRET
    }

    net_connect = ConnectHandler(**device)
    net_connect.enable()

    trunking_vlan = "4000"
    vlan_check = "none"

    vlan_status = net_connect.send_command("show vlan", use_textfsm=True)
    for vlan in vlan_status:
        if vlan['vlan_id'] == target:
            vlan_check = "exists"
            print(f"Vlan {target} exists. No need to create")
            break
        else:
            vlan_check = "not-exist"
            print(f"Vlan {target} does not exist. Need to create")

    # create target vlan if it doesn't exist
    if vlan_check == "not-exist":
        vlan_commands = [
            f'vlan {target}',
            f'name {name}',
            'end'
        ]
        print(f"Need to create vlan {target}")
        net_connect.send_config_set(vlan_commands)

    # change access ports from source vlan to target vlan
    inter_status = net_connect.send_command("show interface status", use_textfsm=True)
    for iface in inter_status:
        access_config_commands = [
            f"interface {iface['port']}",
            'switchport mode access',
            f'switchport access vlan {target}',
            'end'
        ]
        if iface['vlan'] == source:
            print(f"Need to change vlan on {iface['port']}")
            net_connect.send_config_set(access_config_commands)
        else:
            print("Do NOT need to change vlan on " + iface['port'])

    # trunk target vlan
    trunk_status = net_connect.send_command(f"show spanning-tree vlan {trunking_vlan}", use_textfsm=True)
    for iface in trunk_status:
        if iface['type'] == "Shr " or iface['type'] == "P2p ":
            trunk_config_commands = [
                f"interface {iface['interface']}",
                f'switchport trunk allowed vlan add {target}',
                'end'
            ]
            print(f"Need to trunk vlan on {iface['interface']}")
            net_connect.send_config_set(trunk_config_commands)
        else:
            print(f"Do NOT need to trunk vlan on {iface['interface']}")


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['vlan_change']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.0.4,<9.0.0',
 'netmiko>=3.4.0,<4.0.0',
 'python-dotenv>=0.19.2,<0.20.0']

entry_points = \
{'console_scripts': ['vlanchange = vlan_change.cli:cli']}

setup_kwargs = {
    'name': 'vlan-change',
    'version': '0.1.0',
    'description': 'Simple program to change vlans on ports',
    'long_description': None,
    'author': 'Angelo Poggi',
    'author_email': 'angelo.poggi@opti9tech.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
